pub enum Error {
SocketError,
AddrInUse,
EventChannelInitialized,
DaemonNotRunning,
NoLibrary,
LibraryNotAccessible,
CacheDirError(String),
DataDirError(String),
QuitDisabled,
RaiseDisabled,
SetFullscreenDisabled,
}Variants
SocketError
Socket creation failed.
AddrInUse
The socket address is already in use.
EventChannelInitialized
Emitted when the daemon event channel is already initialized when starting the daemon.
This likely means a second daemon was started in the same context.
DaemonNotRunning
The event channel is not initialized, which likely means that the daemon isn’t running.
NoLibrary
The provided music library path is not a directory or doesn’t exist.
LibraryNotAccessible
Cannot access the music library due to a permission issue.
CacheDirError(String)
The cache directory could not be initialized.
This is usually a result of a permission issue.
DataDirError(String)
The data directory could not be initialized.
This is usually a result of a permission issue.
QuitDisabled
Quit requests from external clients are not allowed.
RaiseDisabled
Raise requests are not allowed.
SetFullscreenDisabled
Toggling fullscreen mode by external clients is not allowed.