stop

Function stop 

pub fn stop() -> Result<(), Error>
Stop a running daemon instance.

This has the same effect as sending a Command::Shutdown to the daemon, but it bypasses the requirement to connect to it over a local socket.

If a daemon is not running, Error::DaemonNotRunning will be returned.