AddrClaimMode

Enum AddrClaimMode 

pub enum AddrClaimMode {
    DoNotClaim,
    ClaimIfUnresponsive,
    ForceClaim,
}
Defines under which conditions should the daemon claim an occupied socket address.

This is only effective if filesystem sockets are used.

Variants



DoNotClaim

Do not claim the socket address under any circumstances.



ClaimIfUnresponsive

Only claim the socket address if there is no response to ping commands from the process that listens on the socket.



ForceClaim

Force claim the socket address.