pub enum Error {
SocketError,
AddrInUse,
EventChannelInitialized,
DaemonNotRunning,
NoLibrary,
LibraryNotAccessible,
CacheDirError(String),
DataDirError(String),
ConfigNotInitialized,
}Variants
SocketError
Could not obtain the daemon socket address.
AddrInUse
The socket address is already in use.
EventChannelInitialized
Emitted when the daemon event channel is already initialized when starting the daemon.
This likely means a second daemon was started in the same context.
DaemonNotRunning
The event channel is not initialized, which likely means that there is no daemon running.
NoLibrary
LibraryNotAccessible
CacheDirError(String)
DataDirError(String)
ConfigNotInitialized